@@ -3,7 +3,9 @@
 import os
 import sys
 import inspect
+import six
 
+from .compat import is_bound_method
 from .exceptions import InvalidTask, InvalidCommand, InvalidDodoFile
 from .task import Task, dict_to_task
 
@@ -100,16 +102,28 @@ def load_tasks(dodo_module, command_names=()):
     funcs = []
     prefix_len = len(TASK_STRING)
     # get all functions defined in the module
-    for name, ref in dodo_module.iteritems():
-        # ignore functions that are not a task (by its name)
+    for name, ref in six.iteritems(dodo_module):
+
+        # function is a task creator because of its name
         if inspect.isfunction(ref) and name.startswith(TASK_STRING):
             # remove TASK_STRING prefix from name
             task_name = name[prefix_len:]
+
+        # object is a task creator because it contains the special method
         elif hasattr(ref, 'create_doit_tasks'):
             ref = ref.create_doit_tasks
+            # If create_doit_tasks is a method, it should be called only
+            # if it is bounded to an object.
+            # This avoids calling it for the class definition.
+            argspec = inspect.getargspec(ref)
+            if len(argspec.args) != (1 if is_bound_method(ref) else 0):
+                continue
             task_name = name
+
+        # ignore functions that are not a task creator
         elif True: # coverage can't get "else: continue"
             continue
+
         # tasks cant have name of commands
         if task_name in command_names:
             msg = ("Task can't be called '%s' because this is a command name."+
@@ -174,11 +188,24 @@ def _generate_task_from_yield(tasks, func_name, task_dict, gen_doc):
     # if has 'name' this is a sub-task
     if 'name' in task_dict:
         basename = basename or func_name
+        # if subname is None attributes from group task
+        if task_dict['name'] is None:
+            task_dict['name'] = basename
+            task_dict['actions'] = None
+            group_task = dict_to_task(task_dict)
+            group_task.has_subtask = True
+            tasks[basename] = group_task
+            return
+
         # name is '<task>.<subtask>'
-        task_dict['name'] = "%s:%s"% (basename, task_dict['name'])
+        full_name = "%s:%s"% (basename, task_dict['name'])
+        if full_name in tasks:
+            raise InvalidTask(msg_dup % (func_name, full_name))
+        task_dict['name'] = full_name
         sub_task = dict_to_task(task_dict)
         sub_task.is_subtask = True
 
+        # get/create task group
         group_task = tasks.get(basename)
         if group_task:
             if not group_task.has_subtask:
@@ -224,7 +251,7 @@ def generate_tasks(func_name, gen_result, gen_doc=None):
             _generate_task_from_yield(tasks, func_name, task_dict, x_doc)
 
         if tasks:
-            return tasks.values()
+            return list(six.itervalues(tasks))
         else:
             # special case task_generator did not generate any task
             # create an empty group task
@@ -236,7 +263,3 @@ def generate_tasks(func_name, gen_result, gen_doc=None):
     raise InvalidTask(
         "Task '%s'. Must return a dictionary or generator. Got %s" %
         (func_name, type(gen_result)))
-
-
-
-
