@@ -9,13 +9,20 @@ from doit.filewatch import FileModifyWatcher
 
 class TestFileWatcher(object):
     def testInit(self, cwd):
+        dir1 = 'data3'
         file1, file2 = 'data/w1.txt', 'data/w2.txt'
-        fw = FileModifyWatcher((file1, file2))
+        fw = FileModifyWatcher((file1, file2, dir1))
         # file_list contains absolute paths
+        assert 2 == len(fw.file_list)
         assert os.path.abspath(file1) in fw.file_list
         assert os.path.abspath(file2) in fw.file_list
         # watch_dirs
+        assert 2 == len(fw.watch_dirs)
         assert os.path.join(cwd['current'], 'data') in fw.watch_dirs
+        assert os.path.join(cwd['current'], 'data3') in fw.watch_dirs
+        # notify_dirs
+        assert 1 == len(fw.notify_dirs)
+        assert os.path.join(cwd['current'], 'data3') in fw.notify_dirs
 
 
     def testUnsuportedPlatform(self, monkeypatch):
